##  IT Strategy as the Basis for Application Rationalization
Before you begin your application rationalization, take your time to understand where you stand today, where you want to go, and how to get there. Understanding your strategy and playground are key prerequisites to set up a successful application rationalization initiative.
These are the key steps in understanding your strategy:
  1. Review your IT and business strategy documents. Make sure to understand how the current strategy might influence your initiative.
  2. Understand what success means for your application rationalization initiative. Based on the outcome, define meaningful and business-driven KPIs to show and measure the progress of the initiative as well as the return on investment.
  3. Define your major strategy cornerstones as well as the targets of your application rationalization initiative with the corresponding objective fact sheets, see [Objective Modeling Guidelines](https://help.sap.com/docs/leanix/ea/objective-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model objectives. This includes best practices and applicable use cases, and common antipatterns."). Link them with parent/children relations to outline how they work together.
  4. Identify relevant stakeholders. Conduct a proper stakeholder assessment and categorize them via interest and power to better understand their influence, interest, and level of participation in the application rationalization initiative. Define different change and communication strategies for each stakeholder group.
![Stakeholder matrix with influence and interest axes, showing four quadrants for engagement strategies.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio37f4dccb7e424c838e0949440c432702_HiRes.png)
  5. Select a methodology for the application rationalization. To be able to make transparent and data-based rationalization decisions, use a methodology that fits with your IT strategy and the goals of the initiative. [Gartner’s TIME Model](https://help.sap.com/docs/leanix/ea/time "https://help.sap.com/docs/leanix/ea/time") is one recommended option that clusters your applications into 4 quadrants: Tolerate, Invest, Migrate, Eliminate. Depending on where you stand and where you want to go, you will interpret these quadrants differently. Migrate could point to a lift-and-shift to the Cloud or to a replacement with a SaaS solution. This step is essential to understand how to proceed with the results from your assessment at the end of the initiative.
